@@ -1,15 +1,21 @@
 use crate::cgmath_2d;
 use cgmath::ulps_eq;
-#[cfg(feature = "impl-rayon")]
+#[cfg(feature = "rayon")]
 use rayon::prelude::*;
 use std::cmp::Ordering;
 use std::marker::PhantomData;
 
-pub struct ConvexHull<T: cgmath::BaseFloat + Sync> {
+pub struct ConvexHull<T>
+where
+    T: cgmath::BaseFloat + Sync,
+{
     pd: PhantomData<T>,
 }
 
-impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
+impl<T> ConvexHull<T>
+where
+    T: cgmath::BaseFloat + Sync,
+{
     /// finds the point with lowest x
     fn find_lowest_x(linestring: &[cgmath::Point2<T>]) -> (usize, cgmath::Point2<T>) {
         let mut lowest = linestring[0];
@@ -301,6 +307,8 @@ impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
     /// # use linestring::cgmath_2d;
     /// # use linestring::cgmath_2d::convex_hull;
     /// # use rand::{Rng, SeedableRng};
+    /// # use cgmath::AbsDiffEq;
+    /// # use cgmath::UlpsEq;
     ///
     /// let mut rng = rand_chacha::ChaCha8Rng::seed_from_u64(38);
     /// let mut points = Vec::<cgmath::Point2<f32>>::new();
@@ -321,11 +329,16 @@ impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
     /// let b = cgmath_2d::LineString2::<f32>::default().with_points(points);
     /// let b = convex_hull::ConvexHull::graham_scan(b.points().iter());
     ///
-    /// assert!(convex_hull::ConvexHull::contains(&a, &b));
-    /// assert!(!convex_hull::ConvexHull::contains(&b, &a));
+    /// assert!(convex_hull::ConvexHull::contains(&a, &b, f32::default_epsilon(), f32::default_max_ulps()));
+    /// assert!(!convex_hull::ConvexHull::contains(&b, &a, f32::default_epsilon(), f32::default_max_ulps()));
     ///```
-    #[cfg(not(feature = "impl-rayon"))]
-    pub fn contains(a: &cgmath_2d::LineString2<T>, b: &cgmath_2d::LineString2<T>) -> bool {
+    #[cfg(not(feature = "rayon"))]
+    pub fn contains(
+        a: &cgmath_2d::LineString2<T>,
+        b: &cgmath_2d::LineString2<T>,
+        epsilon: T::Epsilon,
+        max_ulps: u32,
+    ) -> bool {
         if a.len() <= 1 {
             return false;
         }
@@ -339,7 +352,9 @@ impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
             for l in a.as_lines().iter().skip(step1).step_by(4) {
                 for step2 in 0..4 {
                     for p in b.points.iter().skip(step2).step_by(4) {
-                        if !Self::is_point_left_allow_collinear(&l.start, &l.end, p) {
+                        if !Self::is_point_left_allow_collinear_ulps(
+                            &l.start, &l.end, p, epsilon, max_ulps,
+                        ) {
                             //println!("The point {:?} is not left of {:?}", p, l);
                             return false;
                         }
@@ -380,7 +395,7 @@ impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
     /// assert!(convex_hull::ConvexHull::contains(&a, &b, f32::default_epsilon(), f32::default_max_ulps()));
     /// assert!(!convex_hull::ConvexHull::contains(&b, &a, f32::default_epsilon(), f32::default_max_ulps()));
     ///```
-    #[cfg(feature = "impl-rayon")]
+    #[cfg(feature = "rayon")]
     pub fn contains(
         a: &cgmath_2d::LineString2<T>,
         b: &cgmath_2d::LineString2<T>,
@@ -431,7 +446,7 @@ impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
     /// assert!(!convex_hull::ConvexHull::contains_point_exclusive(&hull, &[10.0,9.99999].into()));
     ///
     ///```
-    #[cfg(feature = "impl-rayon")]
+    #[cfg(feature = "rayon")]
     pub fn contains_point_exclusive(a: &cgmath_2d::LineString2<T>, p: &cgmath::Point2<T>) -> bool {
         if a.len() <= 1 {
             return false;
@@ -466,7 +481,7 @@ impl<T: cgmath::BaseFloat + Sync> ConvexHull<T> {
     /// assert!(convex_hull::ConvexHull::contains_point_inclusive(&hull, &[9.999,5.0].into()));
     /// assert!(convex_hull::ConvexHull::contains_point_inclusive(&hull, &[10.0,5.0].into()));
     ///```
-    #[cfg(feature = "impl-rayon")]
+    #[cfg(feature = "rayon")]
     pub fn contains_point_inclusive(a: &cgmath_2d::LineString2<T>, p: &cgmath::Point2<T>) -> bool {
         if a.len() <= 1 {
             return false;
