@@ -84,7 +84,7 @@ impl Plane {
     ///
     /// It's not possible to compare to zero exactly because blender
     /// leaves some decimal in coordinates that's suppose to be zero.
-    pub fn get_plane<T>(aabb: &Aabb3<T>) -> Option<Plane>
+    pub fn get_plane<T>(aabb: &Aabb3<T>) -> Option<Self>
     where
         T: cgmath::BaseFloat + Sync + cgmath::AbsDiffEq<Epsilon = T>,
     {
@@ -311,7 +311,7 @@ where
 {
     #[inline(always)]
     fn partial_cmp(&self, other: &Self) -> Option<std::cmp::Ordering> {
-        Some(self.cmp(&other))
+        Some(self.cmp(other))
     }
 }
 impl<T> Ord for PriorityDistance<T>
