@@ -60,7 +60,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     pub pos: mint::Point2<T>,
 }
@@ -72,7 +74,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     pub fn new(x: T, y: T) -> Self {
         Self {
@@ -88,7 +92,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         f.debug_tuple("")
@@ -105,7 +111,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     #[inline(always)]
     fn partial_cmp(&self, other: &Self) -> Option<cmp::Ordering> {
@@ -128,7 +136,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     /// It should be impossible for a !is_finite() number to be added to SiteEventKey
     #[inline(always)]
@@ -144,7 +154,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     #[inline(always)]
     fn eq(&self, other: &Self) -> bool {
@@ -159,6 +171,8 @@ impl<T> Eq for SiteEventKey<T> where
         + approx::UlpsEq
         + Sync
         + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>
 {
 }
 
@@ -173,7 +187,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     best_left: Option<T>,
     slope: MinMaxSlope<T>,
@@ -187,7 +203,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     fn new() -> Self {
         Self {
@@ -271,7 +289,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     best_left: Option<T>, // slope
     candidates_left: Vec<usize>,
@@ -287,7 +307,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     fn new() -> Self {
         Self {
@@ -412,7 +434,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     drop: Option<Vec<usize>>,
     add: Option<Vec<usize>>,
@@ -428,7 +452,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     pub(crate) fn with_intersection(i: &[usize]) -> Self {
         Self {
@@ -474,7 +500,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     // line equation: y=slope*x+d => d=y-slope*x => x = (y-d)/slope
     let y1 = other.start.y;
@@ -511,7 +539,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     // sweep-line position
     sweepline_pos: mint::Point2<T>,
@@ -544,7 +574,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     fn default() -> Self {
         Self {
@@ -571,7 +603,9 @@ where
         + approx::AbsDiffEq
         + approx::UlpsEq
         + Sync
-        + approx::AbsDiffEq<Epsilon = T>,
+        + approx::AbsDiffEq<Epsilon = T>
+        + approx::UlpsEq<Epsilon = T>
+        + approx::RelativeEq<Epsilon = T>,
 {
     pub fn get_sweepline_pos(&self) -> &mint::Point2<T> {
         &self.sweepline_pos
@@ -844,7 +878,29 @@ where
         })?;
 
         loop {
-            if let Some((key, event)) = site_events.pop_first() {
+            if let Some((key, event)) = {
+                #[cfg(feature = "map_first_last")]
+                {
+                    site_events.pop_first()
+                }
+                #[cfg(not(feature = "map_first_last"))]
+                {
+                    // emulate pop_first
+                    if let Some((first_key, _)) = site_events.iter().next() {
+                        let first_key = first_key.clone();
+                        let v = site_events.remove(&first_key).ok_or_else(|| {
+                            LinestringError::InternalError(format!(
+                                "Found a key to pop but could not remove the value. {}:{}",
+                                file!(),
+                                line!()
+                            ))
+                        })?;
+                        Some((first_key, v))
+                    } else {
+                        None
+                    }
+                }
+            } {
                 self.handle_event(
                     &key,
                     &event,
@@ -1101,7 +1157,7 @@ where
                 #[cfg(feature = "console_trace")]
                 print!("testing intersection between {} and {}: ", left_i, right_i);
 
-                if let Some(intersection_p) = left_l.intersection_point(&right_l) {
+                if let Some(intersection_p) = left_l.intersection_point(right_l) {
                     let intersection_p = intersection_p.single();
                     if !intersection_p.x.is_finite() || !intersection_p.y.is_finite() {
                         return Err(LinestringError::InvalidData(format!(
